AniPrgSize:
	.dw 0
	.dw $288E				;define that the program is an assembly program
AniPrg:
	call _clrScrn
	call _flushallmenus
	call _runindicoff
	jr APpic1


;********************************************************
; -decompresses data that is vertically compressed with
; bmp2asm, by Levi Lansing    (total size=63 bytes)
; -(decompresses data into the video memory - 1024 bytes)
; -de=location of data to decompress
; -destroys- a,b,c,hl,de (points to byte after data)
;********************************************************
decompV:
 ld hl,$FC00        ;point hl to the screen mem
decompLoop:
 ld a,(de)          ;load the first byte of the compressed data
 cp $B7             ;check if it's a marker
 jr nz,DCnorm       ;if it's not, treat it as a normal byte
 inc de             ;if the byte is marked, the next byte tells us the value
 ld a,(de)          ;that is repeated so we
 ld c,a             ;put that in c
 inc de             ;the next byte tells us how many times it's repeated
 ld a,(de)
 ld b,a             ;we will load that into b to be used as a counter
 inc de             ;point to the next byte for later
DCrepeatLoop:
 ld a,c
 xor (hl)
 ld (hl),a
; ld (hl),c          ;put the value in the screen mem once
 push de            ;hide de
 ld de,16
 add hl,de          ;point hl to the next row (16 bytes forward)
 jr nc,DCloop       ;if hl isn't past the end of the screen data ($FFFF), then continue
 ld de,1022         ;if it is, we need to put it back to the next column
 sbc hl,de          ;point hl to the 1st row of the next column
 ld a, l
 cp $10             ;if l is over $10 (16d), it has completed the full screen
 jr c,DCloop        ;jump if it's no over $10 to continue
 pop de             ;restore de again
 ret                ;return from the routine
DCloop:
 pop de             ;restore de
 djnz DCrepeatLoop  ;decrement b and continue loading the same byte down the
                    ;column until b is 0
 jr decompLoop      ;continue with the next byte
DCnorm:
 xor (hl)
 ld (hl),a          ;load the byte into the screen mem
 inc de             ;point de to the next byte
 push de            ;hide it
 ld de, 16
 add hl,de          ;point hl to the next row (16 bytes forward)
 pop de             ;restore de
 jr nc,decompLoop   ;if hl did not go past $FFFF (it would flip to 0+) then continue
 push de            ;hide de again
 ld de, 1022
 sbc hl,de          ;subtracting 1022 from hl put's it at the 1st row of the next column
 ld a, l
 cp $10             ;check if hl is past the first row (if it is, we finished decompressing)
 pop de             ;restore de again
 jr c,decompLoop    ;if we're not done, keep going...
 ret                ;if we get here, we're done and will return from the routine


Clear$FC00:
  ld hl,$FC00
  push hl
  pop de
  inc de
  ld (hl),0
  ld bc,1023
  ldir
  ret


DelayBC:
	halt
	push hl
	call _getky
	pop hl
	cp K_EXIT
	jr z,APExit
	dec bc
	xor a
	cp b
	jr nz,DelayBC
	cp c
	jr nz,DelayBC
	ret

APExit:
	pop bc			;remove call from stack
	pop bc			;remove bc from stack
	jr APEnd

APpic1:
	call $D748+Clear$FC00-AniPrg		;Clear$FC00
	ld hl,$D748+DATA_START-AniPrg		;DATA_START
	ld b,(hl)							;number of frames
	inc hl
APloop:
	push bc
	ex de,hl
	call $D748+decompV-AniPrg			;decompV
	ex de,hl
	ld c,(hl)
	inc hl
	ld b,(hl)
	inc hl
	xor a
	cp b
	jr nz,not0
	cp c
	jr nz,not0
	push hl
	call _getkey
	pop hl
	jr APSkipDelay
not0:
	call $D748+DelayBC-AniPrg			;delayBC
APSkipDelay:
	ld a,(hl)
	inc hl
	push hl
	cp 1
	jr z,APcont
	call $D748+Clear$FC00-AniPrg		;Clear$FC00
APcont:
	pop hl
	pop bc
	djnz APloop
APEnd:
	call $D748+Clear$FC00-AniPrg		;Clear$FC00
	ld de,$0019
	ld (_penCol),de
	ld hl,$D748+TEXT_START-AniPrg
	call _vputs
	ld de,$0725
	ld (_penCol),de
	call _vputs
	ld de,$0E12
	ld (_penCol),de
	call _vputs
	ld de,$0003
	ld (_curRow),de
	ret

TEXT_START:
	.db "Animation  Studio v0.1b",0
	.db "by  Levi  Lansing",0
	.db "puzzlesome@hotmail.com",0

DATA_START:




;****************************************************
;compressV - By Levi Lansing - puzzlesome@hotmail.com
;  compresses a 1024 byte picture at $FC00 to $F600
;  using vertical compression (decompV decompresses)
;input-     data at $FC00
;output-    compressed data at $F600, hl=new size
;destroyed- ix,hl,de,bc,af
;****************************************************
compressV:
	call Compress
	push ix
	pop hl
	ld de,$F600
	and a
	sbc hl,de
	ret				;hl= size of compressed data
Compress:
	ld ix,$F600
	ld hl,$FC00
	ld (Temp),hl
	ld de,16
CVcont:
	ld c,(hl)
	ld a,$B7
	cp c
	jr z,isKey1
	call CVfindrepeat
	dec b
	ld a,2
	cp b
	jr nc,notEnough
	inc b
	ld (ix),$B7
	ld (ix+1),c
	ld (ix+2),b
	inc ix
	inc ix
	inc ix
	jr CVcont
notEnough:
	inc b
notEnoughLP:
	ld (ix),c
	inc ix
	djnz notEnoughLP
	jr CVcont
isKey1:
	call CVfindrepeat
	ld (ix),$B7
	ld (ix+1),c
	ld (ix+2),b
	inc ix
	inc ix
	inc ix
	jr CVcont
CVfindrepeat:
	ld b,1
CVloop1:
	add hl,de
	ld a,$FB
	cp h
	jr c,CVhlok2
	ld hl,(Temp)
	inc hl
	ld a,$10
	cp l
	jr z,CV_DONE_repeat
	ld (Temp),hl
CVhlok2:
	ld a,(hl)
	cp c
	ret nz
	xor a
	cp b
	ret z
	inc b
	jr CVloop1
CV_DONE_repeat:
	ld a,$B7
	cp c
	jr nz,CVnorm
	ld (ix),$B7
	ld (ix+1),c
	ld (ix+2),b
	inc ix
	inc ix
	inc ix
	ret
CVnorm:
	dec b
	ld a,2
	cp b
	jr nc,notEnough2
	inc b
	ld (ix),$B7
	ld (ix+1),c
	ld (ix+2),b
	inc ix
	inc ix
	inc ix
	pop hl				;clear last call so we return from the whole routine
	ret
notEnough2:
	inc b
notEnoughLP2
	ld (ix),c
	inc ix
	djnz notEnoughLP2
	pop hl				;clear last call so we return from the whole routine
	ret





Delay:
	push bc
	ld b,200
d2:
	HALT
	djnz d2
	pop bc
	ret






